==> chromium-browser_45.0.2454.101.orig.tar.xz: chromium-45.0.2454.101/chrome/browser/ui/cocoa/extensions/extension_message_bubble_bridge.h <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_COCOA_EXTENSIONS_EXTENSION_MESSAGE_BUBBLE_BRIDGE_H_
#define CHROME_BROWSER_UI_COCOA_EXTENSIONS_EXTENSION_MESSAGE_BUBBLE_BRIDGE_H_

#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "chrome/browser/extensions/extension_message_bubble.h"
#include "chrome/browser/ui/toolbar/toolbar_actions_bar_bubble_delegate.h"

@class ToolbarActionsBarBubbleMac;

namespace extensions {
class ExtensionMessageBubbleController;
}

// A bridge between an ExtensionMessageBubbleController and a
// ToolbarActionsBarBubble.
class ExtensionMessageBubbleBridge : public extensions::ExtensionMessageBubble,
                                     public ToolbarActionsBarBubbleDelegate {
 public:
  ExtensionMessageBubbleBridge(
      scoped_ptr<extensions::ExtensionMessageBubbleController> controller,
      bool anchored_to_extension);
  ~ExtensionMessageBubbleBridge() override;

  void SetBubble(ToolbarActionsBarBubbleMac* bubble);

  extensions::ExtensionMessageBubbleController* controller() {
    return controller_.get();
  }

 private:
  // extensions::ExtensionMessageBubble:
  void Show() override;

  // ToolbarActionsBarBubbleDelegate:
  base::string16 GetHeadingText() override;
  base::string16 GetBodyText() override;
  base::string16 GetItemListText() override;
  base::string16 GetActionButtonText() override;
  base::string16 GetDismissButtonText() override;
  base::string16 GetLearnMoreButtonText() override;
  void OnBubbleShown() override;
  void OnBubbleClosed(CloseAction action) override;

  scoped_ptr<extensions::ExtensionMessageBubbleController> controller_;

  // True if the bubble is anchored to an extension action.
  bool anchored_to_extension_;

  ToolbarActionsBarBubbleMac* bubble_;

  DISALLOW_COPY_AND_ASSIGN(ExtensionMessageBubbleBridge);
};

#endif  // CHROME_BROWSER_UI_COCOA_EXTENSIONS_EXTENSION_MESSAGE_BUBBLE_BRIDGE_H_

==> chromium-browser_49.0.2623.108.orig.tar.xz: chromium-49.0.2623.108/chrome/browser/ui/cocoa/extensions/extension_message_bubble_bridge.h <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_UI_COCOA_EXTENSIONS_EXTENSION_MESSAGE_BUBBLE_BRIDGE_H_
#define CHROME_BROWSER_UI_COCOA_EXTENSIONS_EXTENSION_MESSAGE_BUBBLE_BRIDGE_H_

#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "chrome/browser/ui/toolbar/toolbar_actions_bar_bubble_delegate.h"

@class ToolbarActionsBarBubbleMac;

namespace extensions {
class ExtensionMessageBubbleController;
}

// A bridge between an ExtensionMessageBubbleController and a
// ToolbarActionsBarBubble.
class ExtensionMessageBubbleBridge : public ToolbarActionsBarBubbleDelegate {
 public:
  ExtensionMessageBubbleBridge(
      scoped_ptr<extensions::ExtensionMessageBubbleController> controller,
      bool anchored_to_extension);
  ~ExtensionMessageBubbleBridge() override;

 private:
  // ToolbarActionsBarBubbleDelegate:
  base::string16 GetHeadingText() override;
  base::string16 GetBodyText() override;
  base::string16 GetItemListText() override;
  base::string16 GetActionButtonText() override;
  base::string16 GetDismissButtonText() override;
  base::string16 GetLearnMoreButtonText() override;
  void OnBubbleShown() override;
  void OnBubbleClosed(CloseAction action) override;

  scoped_ptr<extensions::ExtensionMessageBubbleController> controller_;

  // True if the bubble is anchored to an extension action.
  bool anchored_to_extension_;

  DISALLOW_COPY_AND_ASSIGN(ExtensionMessageBubbleBridge);
};

#endif  // CHROME_BROWSER_UI_COCOA_EXTENSIONS_EXTENSION_MESSAGE_BUBBLE_BRIDGE_H_
